/* istanbul ignore file */
import { Layer, Util } from "leaflet";
import { getBboxPolygon } from "../utils/geometry";
import difference from "@turf/difference";
import union from "@turf/union";
const PolyDiff = Layer.extend({
    options: {
        eventName: "polydiff",
    },
    initialize: function (opts) {
        Util.setOptions(this, opts);
    },
    onAdd: function (map) {
        this._lastSeenArea = getBboxPolygon(map.getBounds());
        this._map = map;
        map.on("moveend", this._onMoveEnd, this);
    },
    onRemove: function (map) {
        map.off("moveend", this._onMoveEnd, this);
    },
    _onMoveEnd() {
        const { options: { eventName }, } = this;
        const mapPoly = getBboxPolygon(this._map.getBounds());
        const diff = difference(mapPoly, this._lastSeenArea);
        const _union = union(this._lastSeenArea, mapPoly);
        if (!_union)
            return;
        this._lastSeenArea = _union;
        if (!diff)
            return;
        this._map.fire(eventName, { diff });
    },
});
export { PolyDiff };
export default function (opts) {
    // @ts-ignore
    return new PolyDiff(opts);
}
